@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <QDialog>
 
-namespace MailTransport {
+namespace MailTransport
+{
 class Transport;
 class SMTPConfigWidget;
 class SmtpConfigDialog : public QDialog
