@@ -11,10 +11,10 @@
 #include <QPointer>
 #include <QPushButton>
 
+#include <KTextEdit>
 #include <QApplication>
 #include <QDateTimeEdit>
 #include <QLineEdit>
-#include <KTextEdit>
 #include <QVBoxLayout>
 #include <control.h>
 
@@ -24,8 +24,8 @@
 
 #include <kmailtransportakonadi/dispatchmodeattribute.h>
 #include <kmailtransportakonadi/messagequeuejob.h>
-#include <transportmanager.h>
 #include <transport.h>
+#include <transportmanager.h>
 
 using namespace KMime;
 using namespace MailTransport;
@@ -35,7 +35,7 @@ MessageQueuer::MessageQueuer()
     if (!Akonadi::Control::start()) {
         qFatal("Could not start Akonadi server.");
     }
-    auto *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(0, 0, 0, 0);
 
     mComboBox = new TransportComboBox(this);
@@ -89,7 +89,7 @@ void MessageQueuer::sendOnDateClicked()
 {
     QPointer<QDialog> dialog = new QDialog(this);
     auto layout = new QVBoxLayout(dialog);
-    auto *dt = new QDateTimeEdit(dialog);
+    auto dt = new QDateTimeEdit(dialog);
     dt->setDateTime(QDateTime::currentDateTime());
     dt->setDisplayFormat(QStringLiteral("hh:mm:ss"));
     layout->addWidget(dt);
@@ -116,25 +116,19 @@ MessageQueueJob *MessageQueuer::createQueueJob()
     msg->setContent(QByteArray("\n") + mMailEdit->document()->toPlainText().toLatin1());
     qDebug() << "msg:" << msg->encodedContent(true);
 
-    auto *job = new MessageQueueJob();
+    auto job = new MessageQueueJob();
     job->setMessage(msg);
     job->transportAttribute().setTransportId(mComboBox->currentTransportId());
     // default dispatch mode
     // default sent-mail collection
     job->addressAttribute().setFrom(mSenderEdit->text());
-    job->addressAttribute().setTo(mToEdit->text().isEmpty()
-                                  ? QStringList() : mToEdit->text().split(QLatin1Char(',')));
-    job->addressAttribute().setCc(mCcEdit->text().isEmpty()
-                                  ? QStringList() : mCcEdit->text().split(QLatin1Char(',')));
-    job->addressAttribute().setBcc(mBccEdit->text().isEmpty()
-                                   ? QStringList() : mBccEdit->text().split(QLatin1Char(',')));
+    job->addressAttribute().setTo(mToEdit->text().isEmpty() ? QStringList() : mToEdit->text().split(QLatin1Char(',')));
+    job->addressAttribute().setCc(mCcEdit->text().isEmpty() ? QStringList() : mCcEdit->text().split(QLatin1Char(',')));
+    job->addressAttribute().setBcc(mBccEdit->text().isEmpty() ? QStringList() : mBccEdit->text().split(QLatin1Char(',')));
 
-    connect(job, &MessageQueueJob::result,
-            this, &MessageQueuer::jobResult);
-    connect(job, SIGNAL(percent(KJob*,ulong)),
-            SLOT(jobPercent(KJob*,ulong)));
-    connect(job, &KJob::infoMessage,
-            this, &MessageQueuer::jobInfoMessage);
+    connect(job, &MessageQueueJob::result, this, &MessageQueuer::jobResult);
+    connect(job, SIGNAL(percent(KJob *, ulong)), SLOT(jobPercent(KJob *, ulong)));
+    connect(job, &KJob::infoMessage, this, &MessageQueuer::jobInfoMessage);
 
     return job;
 }
@@ -144,7 +138,7 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("messagequeuer"));
 
-    auto *t = new MessageQueuer();
+    auto t = new MessageQueuer();
     t->show();
     app.exec();
     delete t;
@@ -161,13 +155,13 @@ void MessageQueuer::jobResult(KJob *job)
 
 void MessageQueuer::jobPercent(KJob *job, unsigned long percent)
 {
-    Q_UNUSED(job);
+    Q_UNUSED(job)
     qDebug() << percent << "%";
 }
 
 void MessageQueuer::jobInfoMessage(KJob *job, const QString &info, const QString &info2)
 {
-    Q_UNUSED(job);
+    Q_UNUSED(job)
     qDebug() << info;
     qDebug() << info2;
 }
